
' A stripped-down demo that shows how you can treat a virtual resolution as
' if it's a fixed display size and simply hard-code your positions for that
' display size if you want to. It'll still be scaled to fit any size of
' device correctly.

Import mojo
Import autofit

Class Game Extends App

	Method OnCreate ()
		SetUpdateRate 60
		SetVirtualDisplay 800, 480
	End
	
	Method OnUpdate ()
	End
	
	Method OnRender ()
		
		UpdateVirtualDisplay
		
		Cls 32, 64, 96
		
		' All positions hard-coded for 800 x 480, so screen-centre is 400, 240...
		
		SetColor 255, 0, 0
		DrawLine 400, 240 - 5, 400, 240 + 5
		DrawLine 400 - 5, 240, 400 + 5, 240
		
		SetColor 255, 255, 255
		DrawRect 400 - 1, 240 - 1, 2, 2
		
		' Hard-coded text will be positioned correctly on any device,
		' regardless of its 'real' resolution...
		
		DrawText "SPACE to draw at real resolution!", 10, 460

		' Draw a rectangle within virtual display:
		
		SetColor 255, 255, 255
		DrawRect 0, 0, 320, 240
		
		' SPACE shows use of virtual display followed by virtual display...
		
		' Here, we...
		
		' 1) store the virtual display settings with StoreVirtualDisplay;
		' 2) use the full display area with DisableVirtualDisplay;
		' 3) put the virtual display back in place with RestoreVirtualDisplay.
		
		' Note: if you only intend to draw to the 'real' display AFTER all other drawing
		' is complete (eg. control overlay), and have no intention of drawing anything else,
		' you don't need to use StoreVirtualDisplay or RestoreVirtualDisplay.
		
		If KeyDown (KEY_SPACE)
		
			StoreVirtualDisplay					' Store the virtual display settings
				
				DisableVirtualDisplay			' Use 'real' device display area
				
				SetColor 0, 255, 0
				DrawRect 0, 0, 320, 240			' GREEN rectangle
			
				SetColor 255, 255, 255
				DrawText "Real display", 0, 0
				
			RestoreVirtualDisplay				' Put virtual display back in place
			
			' Draw within virtual display again...
			
			SetColor 255, 0, 0
			DrawRect 0, 0, 320, 240				' RED rectangle
		
			SetColor 255, 255, 255
			DrawText "Back to virtual display", 0, 0
				
		Endif

	End
	
End

Function Main ()
	New Game
End
